.. Flask-Storages documentation master file, created by
   sphinx-quickstart on Mon Oct  6 12:44:29 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Flask-FS's documentation!
====================================

Flask-FS provide a simple and flexible file storage interface for Flask.
It is inspired by Django file storage.


Documentation
=============

This part of the documentation will show you how to get started in using
Flask-FS with Flask.

.. toctree::
    :maxdepth: 2

    installation
    quickstart
    config
    backends
    mongoengine


API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

Additional Notes
----------------

.. toctree::
   :maxdepth: 2

   contributing
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
